@@ -6,11 +6,10 @@ import re
 import string
 import psutil
 
-from pathlib import Path
 from platform import uname
 from rich.console import Console
 import subprocess
-from typing import Dict, Union
+from typing import Dict, Union, Text, Iterator
 from collections import OrderedDict
 
 from doing.exceptions import ConfigurationError, devops_error_tips
@@ -96,22 +95,42 @@ def get_repo_name():
     return repo_name
 
 
-def find_dotfile(filename: str) -> str:
+def _walk_to_root(path: Text) -> Iterator[Text]:
+    """
+    Yield directories starting from the given directory up to the root.
+
+    Credits:
+    https://github.com/theskumar/python-dotenv
+    """
+    if not os.path.exists(path):
+        raise IOError("Starting path not found")
+
+    if os.path.isfile(path):
+        path = os.path.dirname(path)
+
+    last_dir = None
+    current_dir = os.path.abspath(path)
+    while last_dir != current_dir:
+        yield current_dir
+        parent_dir = os.path.abspath(os.path.join(current_dir, os.path.pardir))
+        last_dir, current_dir = current_dir, parent_dir
+
+
+def find_dotfile() -> str:
     """
     Recursively search directories upwards for a specific file.
-
-    Args:
-        filename (str): name of the file.
     """
-    wd = Path(os.getcwd())
+    filename = ".doing-cli-config.yml"
+    filename2 = ".doing-cli-config.yaml"
+    path = os.getcwd()
 
-    i = 0
-    while i != 15 or wd == Path("/"):
-        filepath = wd / Path(filename)
-        if filepath.is_file():
-            return str(filepath)
-        wd = wd.parent
-        i += 1
+    for dirname in _walk_to_root(path):
+        check_path = os.path.join(dirname, filename)
+        if os.path.isfile(check_path):
+            return check_path
+        check_path = os.path.join(dirname, filename2)
+        if os.path.isfile(check_path):
+            return check_path
 
     return ""
 
@@ -142,11 +161,7 @@ def get_config(key: str = "", fallback: Union[str, Dict] = None, envvar_prefix:
             return env_var
 
     # Find the config file
-    conf_path = find_dotfile(".doing-cli-config.yml")
-
-    # Allow for .yaml syntax as well
-    if not conf_path:
-        conf_path = find_dotfile(".doing-cli-config.yaml")
+    conf_path = find_dotfile()
 
     if not conf_path:
         if fallback is not None:
